import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/Radhakrishna246/782bb24a0af8a05c6ebcb0572601a9ab/raw/c87ad1c40b102a552157116f05c7ac547c6b38c9/iris.csv';  

// Format the Data from the URI response
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);



const main = async () => {
  
  // Creating a new Scatter Plot object
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 20,
      bottom: 70,
      left: 70,
    })
    .radius(10);
  
  

  // Plotting the Scatter Plot axes based on the given parameters
  svg.call(plot);

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  // Plotting the data on the Scatter Plot
  let i = 0;
 	plot.xValue((d) => d[columns[i % columns.length]]);
  svg.call(plot);
};
main();



